@@ -6,18 +6,19 @@ import anyio
 import socket
 import json
 import msur_stm_driver.protocol as p
+import os
 """
 Сервис поддерживает связь с аппаратом, принимает телеметрию, отправляет актуальные управляющие воздействия на аппарат с
 частотой 10 Hz
 """
 
 # адрес и порт аппарата
-AUV_PORT = 2030
+AUV_PORT = int(os.getenv('LOCAL_PORT', '2030'))
 # AUV_ADDRESS = '192.168.90.1'
-AUV_ADDRESS = '127.0.0.1'
-LOCAL_PORT = 2065
+AUV_ADDRESS = os.getenv('AUV_ADDRESS', '127.0.0.1')
+LOCAL_PORT = int(os.getenv('LOCAL_PORT', '2065'))
 # LOCAL_ADDRESS = '192.168.90.77'
-LOCAL_ADDRESS = '127.0.0.1'
+LOCAL_ADDRESS = os.getenv('LOCAL_ADDRESS', '127.0.0.1')
 
 # Сокеты для обмена клиента и сервиса
 SERVER_SOCKET = '/tmp/msur-server'
